**Example 1: 请求示例**



Input: 

```
tccli redis AssociateSecurityGroups --cli-unfold-argument  \
    --Product redis \
    --SecurityGroupId sg-ajr1jzgj \
    --InstanceIds crs-eb2w7dto
```

Output: 
```
{
    "Response": {
        "RequestId": "1a42feb9-82087f71-6a0031ac-699a92a1"
    }
}
```

